# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/predict-buffer/predict-buffer-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.predict.predict_api import predict_api_service_pb2 as cogneed__protos_dot_predict_dot_predict__api_dot_predict__api__service__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/predict-buffer/predict-buffer-service.proto',
  package='ai.cogneed.api.predict.predictbuffer',
  syntax='proto3',
  serialized_options=_b('\n$ai.cogneed.api.predict.predictbufferP\001'),
  serialized_pb=_b('\nBcogneed-protos/predict/predict-buffer/predict-buffer-service.proto\x12$ai.cogneed.api.predict.predictbuffer\x1a<cogneed-protos/predict/predict-api/predict-api-service.proto\"{\n\x12PredictionResponse\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12\x18\n\x10prediction_index\x18\x02 \x01(\x05\x12\x13\n\x0bprobability\x18\x03 \x01(\x02\x12\x12\n\nmodel_name\x18\x04 \x01(\t\x12\r\n\x05minor\x18\x05 \x01(\x03\"\xd7\x01\n\x15PredictBufferResponse\x12N\n\nprediction\x18\x01 \x01(\x0b\x32\x38.ai.cogneed.api.predict.predictbuffer.PredictionResponseH\x00\x12P\n\rno_prediction\x18\x02 \x01(\x0b\x32\x37.ai.cogneed.api.predict.predictapi.NoPredictionResponseH\x00\x12\x11\n\x07\x66\x61ilure\x18\x03 \x01(\tH\x00\x42\t\n\x07\x63ontent\"u\n\x14PredictBufferRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\x12\r\n\x05major\x18\x03 \x01(\t\x12\x18\n\x10start_mfcc_index\x18\x04 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x32\x9b\x01\n\x14PredictBufferService\x12\x82\x01\n\x07predict\x12:.ai.cogneed.api.predict.predictbuffer.PredictBufferRequest\x1a;.ai.cogneed.api.predict.predictbuffer.PredictBufferResponseB(\n$ai.cogneed.api.predict.predictbufferP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_predict_dot_predict__api_dot_predict__api__service__pb2.DESCRIPTOR,])




_PREDICTIONRESPONSE = _descriptor.Descriptor(
  name='PredictionResponse',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.num_classes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_index', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.prediction_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probability', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.probability', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.model_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor', full_name='ai.cogneed.api.predict.predictbuffer.PredictionResponse.minor', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=293,
)


_PREDICTBUFFERRESPONSE = _descriptor.Descriptor(
  name='PredictBufferResponse',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.prediction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_prediction', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.no_prediction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.failure', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=296,
  serialized_end=511,
)


_PREDICTBUFFERREQUEST = _descriptor.Descriptor(
  name='PredictBufferRequest',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.major', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_mfcc_index', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.start_mfcc_index', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferRequest.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=630,
)

_PREDICTBUFFERRESPONSE.fields_by_name['prediction'].message_type = _PREDICTIONRESPONSE
_PREDICTBUFFERRESPONSE.fields_by_name['no_prediction'].message_type = cogneed__protos_dot_predict_dot_predict__api_dot_predict__api__service__pb2._NOPREDICTIONRESPONSE
_PREDICTBUFFERRESPONSE.oneofs_by_name['content'].fields.append(
  _PREDICTBUFFERRESPONSE.fields_by_name['prediction'])
_PREDICTBUFFERRESPONSE.fields_by_name['prediction'].containing_oneof = _PREDICTBUFFERRESPONSE.oneofs_by_name['content']
_PREDICTBUFFERRESPONSE.oneofs_by_name['content'].fields.append(
  _PREDICTBUFFERRESPONSE.fields_by_name['no_prediction'])
_PREDICTBUFFERRESPONSE.fields_by_name['no_prediction'].containing_oneof = _PREDICTBUFFERRESPONSE.oneofs_by_name['content']
_PREDICTBUFFERRESPONSE.oneofs_by_name['content'].fields.append(
  _PREDICTBUFFERRESPONSE.fields_by_name['failure'])
_PREDICTBUFFERRESPONSE.fields_by_name['failure'].containing_oneof = _PREDICTBUFFERRESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['PredictionResponse'] = _PREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['PredictBufferResponse'] = _PREDICTBUFFERRESPONSE
DESCRIPTOR.message_types_by_name['PredictBufferRequest'] = _PREDICTBUFFERREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictionResponse = _reflection.GeneratedProtocolMessageType('PredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_buffer.predict_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictbuffer.PredictionResponse)
  ))
_sym_db.RegisterMessage(PredictionResponse)

PredictBufferResponse = _reflection.GeneratedProtocolMessageType('PredictBufferResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTBUFFERRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_buffer.predict_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictbuffer.PredictBufferResponse)
  ))
_sym_db.RegisterMessage(PredictBufferResponse)

PredictBufferRequest = _reflection.GeneratedProtocolMessageType('PredictBufferRequest', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTBUFFERREQUEST,
  __module__ = 'cogneed_protos.predict.predict_buffer.predict_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictbuffer.PredictBufferRequest)
  ))
_sym_db.RegisterMessage(PredictBufferRequest)


DESCRIPTOR._options = None

_PREDICTBUFFERSERVICE = _descriptor.ServiceDescriptor(
  name='PredictBufferService',
  full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=633,
  serialized_end=788,
  methods=[
  _descriptor.MethodDescriptor(
    name='predict',
    full_name='ai.cogneed.api.predict.predictbuffer.PredictBufferService.predict',
    index=0,
    containing_service=None,
    input_type=_PREDICTBUFFERREQUEST,
    output_type=_PREDICTBUFFERRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTBUFFERSERVICE)

DESCRIPTOR.services_by_name['PredictBufferService'] = _PREDICTBUFFERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/trainui/sentence.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/trainui/sentence.proto',
  package='ai.cogneed.api.trainui.sentence',
  syntax='proto3',
  serialized_options=_b('\n\037ai.cogneed.api.trainui.sentenceP\001'),
  serialized_pb=_b('\n4cogneed-protos/ai/cogneed/api/trainui/sentence.proto\x12\x1f\x61i.cogneed.api.trainui.sentence\x1a*cogneed-protos/ai/cogneed/api/common.proto\">\n\x06\x43reate\x12\x10\n\x08use_case\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\x14\n\x04Read\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"S\n\x04List\x12\x10\n\x08use_case\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x15\n\rrows_per_page\x18\x04 \x01(\x05\"\x16\n\x06\x44\x65lete\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"f\n\x08Sentence\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x16\n\x0enum_recordings\x18\x05 \x01(\x05\"Y\n\x0cListResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12:\n\x07results\x18\x02 \x03(\x0b\x32).ai.cogneed.api.trainui.sentence.Sentence2\xbb\x03\n\x0fSentenceService\x12N\n\x06\x63reate\x12\'.ai.cogneed.api.trainui.sentence.Create\x1a\x1b.ai.cogneed.api.AckResponse\x12X\n\x04read\x12%.ai.cogneed.api.trainui.sentence.Read\x1a).ai.cogneed.api.trainui.sentence.Sentence\x12\\\n\x04list\x12%.ai.cogneed.api.trainui.sentence.List\x1a-.ai.cogneed.api.trainui.sentence.ListResponse\x12P\n\x06update\x12).ai.cogneed.api.trainui.sentence.Sentence\x1a\x1b.ai.cogneed.api.AckResponse\x12N\n\x06\x64\x65lete\x12\'.ai.cogneed.api.trainui.sentence.Delete\x1a\x1b.ai.cogneed.api.AckResponseB#\n\x1f\x61i.cogneed.api.trainui.sentenceP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='ai.cogneed.api.trainui.sentence.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.trainui.sentence.Create.use_case', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.sentence.Create.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='ai.cogneed.api.trainui.sentence.Create.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=195,
)


_READ = _descriptor.Descriptor(
  name='Read',
  full_name='ai.cogneed.api.trainui.sentence.Read',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.sentence.Read.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=217,
)


_LIST = _descriptor.Descriptor(
  name='List',
  full_name='ai.cogneed.api.trainui.sentence.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.trainui.sentence.List.use_case', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.sentence.List.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='ai.cogneed.api.trainui.sentence.List.page', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows_per_page', full_name='ai.cogneed.api.trainui.sentence.List.rows_per_page', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=302,
)


_DELETE = _descriptor.Descriptor(
  name='Delete',
  full_name='ai.cogneed.api.trainui.sentence.Delete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.sentence.Delete.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=326,
)


_SENTENCE = _descriptor.Descriptor(
  name='Sentence',
  full_name='ai.cogneed.api.trainui.sentence.Sentence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.sentence.Sentence.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.trainui.sentence.Sentence.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.sentence.Sentence.keyword_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='ai.cogneed.api.trainui.sentence.Sentence.text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_recordings', full_name='ai.cogneed.api.trainui.sentence.Sentence.num_recordings', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=430,
)


_LISTRESPONSE = _descriptor.Descriptor(
  name='ListResponse',
  full_name='ai.cogneed.api.trainui.sentence.ListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='ai.cogneed.api.trainui.sentence.ListResponse.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='ai.cogneed.api.trainui.sentence.ListResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=521,
)

_LISTRESPONSE.fields_by_name['results'].message_type = _SENTENCE
DESCRIPTOR.message_types_by_name['Create'] = _CREATE
DESCRIPTOR.message_types_by_name['Read'] = _READ
DESCRIPTOR.message_types_by_name['List'] = _LIST
DESCRIPTOR.message_types_by_name['Delete'] = _DELETE
DESCRIPTOR.message_types_by_name['Sentence'] = _SENTENCE
DESCRIPTOR.message_types_by_name['ListResponse'] = _LISTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(
  DESCRIPTOR = _CREATE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.sentence_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.sentence.Create)
  ))
_sym_db.RegisterMessage(Create)

Read = _reflection.GeneratedProtocolMessageType('Read', (_message.Message,), dict(
  DESCRIPTOR = _READ,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.sentence_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.sentence.Read)
  ))
_sym_db.RegisterMessage(Read)

List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), dict(
  DESCRIPTOR = _LIST,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.sentence_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.sentence.List)
  ))
_sym_db.RegisterMessage(List)

Delete = _reflection.GeneratedProtocolMessageType('Delete', (_message.Message,), dict(
  DESCRIPTOR = _DELETE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.sentence_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.sentence.Delete)
  ))
_sym_db.RegisterMessage(Delete)

Sentence = _reflection.GeneratedProtocolMessageType('Sentence', (_message.Message,), dict(
  DESCRIPTOR = _SENTENCE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.sentence_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.sentence.Sentence)
  ))
_sym_db.RegisterMessage(Sentence)

ListResponse = _reflection.GeneratedProtocolMessageType('ListResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.sentence_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.sentence.ListResponse)
  ))
_sym_db.RegisterMessage(ListResponse)


DESCRIPTOR._options = None

_SENTENCESERVICE = _descriptor.ServiceDescriptor(
  name='SentenceService',
  full_name='ai.cogneed.api.trainui.sentence.SentenceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=524,
  serialized_end=967,
  methods=[
  _descriptor.MethodDescriptor(
    name='create',
    full_name='ai.cogneed.api.trainui.sentence.SentenceService.create',
    index=0,
    containing_service=None,
    input_type=_CREATE,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='read',
    full_name='ai.cogneed.api.trainui.sentence.SentenceService.read',
    index=1,
    containing_service=None,
    input_type=_READ,
    output_type=_SENTENCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='list',
    full_name='ai.cogneed.api.trainui.sentence.SentenceService.list',
    index=2,
    containing_service=None,
    input_type=_LIST,
    output_type=_LISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='update',
    full_name='ai.cogneed.api.trainui.sentence.SentenceService.update',
    index=3,
    containing_service=None,
    input_type=_SENTENCE,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='delete',
    full_name='ai.cogneed.api.trainui.sentence.SentenceService.delete',
    index=4,
    containing_service=None,
    input_type=_DELETE,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SENTENCESERVICE)

DESCRIPTOR.services_by_name['SentenceService'] = _SENTENCESERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/trainui/tasks.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api.trainui import sentence_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/trainui/tasks.proto',
  package='ai.cogneed.api.trainui.tasks',
  syntax='proto3',
  serialized_options=_b('\n\034ai.cogneed.api.trainui.tasksP\001'),
  serialized_pb=_b('\n1cogneed-protos/ai/cogneed/api/trainui/tasks.proto\x12\x1c\x61i.cogneed.api.trainui.tasks\x1a\x34\x63ogneed-protos/ai/cogneed/api/trainui/sentence.proto\"+\n\x08Progress\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\x05\x12\x0e\n\x06target\x18\x02 \x01(\x05\":\n\x0bTaskRequest\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t2\xd3\x01\n\x0cTasksService\x12\x61\n\x0cget_progress\x12).ai.cogneed.api.trainui.tasks.TaskRequest\x1a&.ai.cogneed.api.trainui.tasks.Progress\x12`\n\x08get_next\x12).ai.cogneed.api.trainui.tasks.TaskRequest\x1a).ai.cogneed.api.trainui.sentence.SentenceB \n\x1c\x61i.cogneed.api.trainui.tasksP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2.DESCRIPTOR,])




_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='ai.cogneed.api.trainui.tasks.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='ai.cogneed.api.trainui.tasks.Progress.current', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='ai.cogneed.api.trainui.tasks.Progress.target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=180,
)


_TASKREQUEST = _descriptor.Descriptor(
  name='TaskRequest',
  full_name='ai.cogneed.api.trainui.tasks.TaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.tasks.TaskRequest.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.tasks.TaskRequest.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=240,
)

DESCRIPTOR.message_types_by_name['Progress'] = _PROGRESS
DESCRIPTOR.message_types_by_name['TaskRequest'] = _TASKREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Progress = _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), dict(
  DESCRIPTOR = _PROGRESS,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.tasks_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.tasks.Progress)
  ))
_sym_db.RegisterMessage(Progress)

TaskRequest = _reflection.GeneratedProtocolMessageType('TaskRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.tasks_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.tasks.TaskRequest)
  ))
_sym_db.RegisterMessage(TaskRequest)


DESCRIPTOR._options = None

_TASKSSERVICE = _descriptor.ServiceDescriptor(
  name='TasksService',
  full_name='ai.cogneed.api.trainui.tasks.TasksService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=243,
  serialized_end=454,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_progress',
    full_name='ai.cogneed.api.trainui.tasks.TasksService.get_progress',
    index=0,
    containing_service=None,
    input_type=_TASKREQUEST,
    output_type=_PROGRESS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_next',
    full_name='ai.cogneed.api.trainui.tasks.TasksService.get_next',
    index=1,
    containing_service=None,
    input_type=_TASKREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2._SENTENCE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TASKSSERVICE)

DESCRIPTOR.services_by_name['TasksService'] = _TASKSSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.trainui import config_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_config__pb2


class ConfigServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.read = channel.unary_unary(
        '/ai.cogneed.api.trainui.config.ConfigService/read',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_config__pb2.ReadRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_config__pb2.Config.FromString,
        )
    self.update = channel.unary_unary(
        '/ai.cogneed.api.trainui.config.ConfigService/update',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_config__pb2.UpdateTarget.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class ConfigServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def read(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ConfigServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'read': grpc.unary_unary_rpc_method_handler(
          servicer.read,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_config__pb2.ReadRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_config__pb2.Config.SerializeToString,
      ),
      'update': grpc.unary_unary_rpc_method_handler(
          servicer.update,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_config__pb2.UpdateTarget.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.trainui.config.ConfigService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.modelconfig import model_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2


class ModelServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.create = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/create',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Create.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )
    self.list = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/list',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.List.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.FromString,
        )
    self.read = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/read',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.FromString,
        )
    self.upgrade = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/upgrade',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
        )
    self.startTraining = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/startTraining',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )
    self.deploy = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/deploy',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )
    self.markAsTrained = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/markAsTrained',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.FromString,
        )


class ModelServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def list(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def read(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def upgrade(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def startTraining(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def deploy(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def markAsTrained(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ModelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'create': grpc.unary_unary_rpc_method_handler(
          servicer.create,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Create.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
      'list': grpc.unary_unary_rpc_method_handler(
          servicer.list,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.List.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.SerializeToString,
      ),
      'read': grpc.unary_unary_rpc_method_handler(
          servicer.read,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.SerializeToString,
      ),
      'upgrade': grpc.unary_unary_rpc_method_handler(
          servicer.upgrade,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
      ),
      'startTraining': grpc.unary_unary_rpc_method_handler(
          servicer.startTraining,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
      'deploy': grpc.unary_unary_rpc_method_handler(
          servicer.deploy,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
      'markAsTrained': grpc.unary_unary_rpc_method_handler(
          servicer.markAsTrained,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ResponseOk.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.modelconfig.model.ModelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.audio_stream.audio_stream_api import audio_stream_api_service_pb2 as cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2
from cogneed_protos.audio_stream.common import common_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2


class StreamAudioServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.init_session = channel.unary_unary(
        '/ai.cogneed.api.audio.audiostream.StreamAudioService/init_session',
        request_serializer=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.InitSessionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.InitSessionResponse.FromString,
        )
    self.send_audio = channel.unary_unary(
        '/ai.cogneed.api.audio.audiostream.StreamAudioService/send_audio',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.AudioBlob.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.Response.FromString,
        )
    self.end_session = channel.unary_unary(
        '/ai.cogneed.api.audio.audiostream.StreamAudioService/end_session',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.EndSessionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.EndSessionResponse.FromString,
        )


class StreamAudioServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def init_session(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def send_audio(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def end_session(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StreamAudioServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'init_session': grpc.unary_unary_rpc_method_handler(
          servicer.init_session,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.InitSessionRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.InitSessionResponse.SerializeToString,
      ),
      'send_audio': grpc.unary_unary_rpc_method_handler(
          servicer.send_audio,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.AudioBlob.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.Response.SerializeToString,
      ),
      'end_session': grpc.unary_unary_rpc_method_handler(
          servicer.end_session,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.EndSessionRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__api_dot_audio__stream__api__service__pb2.EndSessionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.audio.audiostream.StreamAudioService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/common/g711.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/common/g711.proto',
  package='ai.cogneed.audio.decode.g711',
  syntax='proto3',
  serialized_options=_b('\n\034ai.cogneed.audio.decode.g711P\001'),
  serialized_pb=_b('\n-cogneed-protos/audio-stream/common/g711.proto\x12\x1c\x61i.cogneed.audio.decode.g711*)\n\tG711Codec\x12\r\n\tG711_ULAW\x10\x00\x12\r\n\tG711_ALAW\x10\x01\x42 \n\x1c\x61i.cogneed.audio.decode.g711P\x01\x62\x06proto3')
)

_G711CODEC = _descriptor.EnumDescriptor(
  name='G711Codec',
  full_name='ai.cogneed.audio.decode.g711.G711Codec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='G711_ULAW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G711_ALAW', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=79,
  serialized_end=120,
)
_sym_db.RegisterEnumDescriptor(_G711CODEC)

G711Codec = enum_type_wrapper.EnumTypeWrapper(_G711CODEC)
G711_ULAW = 0
G711_ALAW = 1


DESCRIPTOR.enum_types_by_name['G711Codec'] = _G711CODEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/common/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.audio_stream.common import g711_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/common/common.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n/cogneed-protos/audio-stream/common/common.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\x1a-cogneed-protos/audio-stream/common/g711.proto\"\xb4\x01\n\x0b\x41udioFormat\x12\x31\n\x03\x65xt\x18\x01 \x01(\x0e\x32$.ai.cogneed.cloud.speech.v1.AudioExt\x12\x35\n\x05\x63odec\x18\x02 \x01(\x0e\x32&.ai.cogneed.cloud.speech.v1.AudioCodec\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x03\x12\x10\n\x08\x63hannels\x18\x04 \x01(\x05\x12\x14\n\x0csample_width\x18\x05 \x01(\x05\".\n\x0bModelConfig\x12\x10\n\x08use_case\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\t\"\x8d\x01\n\tAudioInfo\x12\x39\n\x06\x66ormat\x18\x01 \x01(\x0b\x32\'.ai.cogneed.cloud.speech.v1.AudioFormatH\x00\x12=\n\ng711_codec\x18\x02 \x01(\x0e\x32\'.ai.cogneed.audio.decode.g711.G711CodecH\x00\x42\x06\n\x04info\"(\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"#\n\x11PersistenceConfig\x12\x0e\n\x06record\x18\x01 \x01(\x08\"\xd3\x01\n\x12InitSessionRequest\x12\x37\n\tuser_info\x18\x01 \x01(\x0b\x32$.ai.cogneed.cloud.speech.v1.UserInfo\x12\x39\n\naudio_info\x18\x02 \x01(\x0b\x32%.ai.cogneed.cloud.speech.v1.AudioInfo\x12I\n\x12persistence_config\x18\x03 \x01(\x0b\x32-.ai.cogneed.cloud.speech.v1.PersistenceConfig\"9\n\x11\x44\x65tectionResponse\x12\x13\n\x0bmillisecond\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"\x1c\n\tAudioBlob\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c*/\n\x08\x41udioExt\x12\x08\n\x04WEBM\x10\x00\x12\x07\n\x03MP3\x10\x01\x12\x07\n\x03WAV\x10\x02\x12\x07\n\x03OGG\x10\x03*+\n\nAudioCodec\x12\x08\n\x04OPUS\x10\x00\x12\n\n\x06VORBIS\x10\x01\x12\x07\n\x03PCM\x10\x02*C\n\nStatusCode\x12\x06\n\x02OK\x10\x00\x12\x10\n\x0cSERVER_ERROR\x10\x01\x12\x1b\n\x17SESSION_DOES_NOT_EXISTS\x10\x02\x42\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2.DESCRIPTOR,])

_AUDIOEXT = _descriptor.EnumDescriptor(
  name='AudioExt',
  full_name='ai.cogneed.cloud.speech.v1.AudioExt',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEBM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP3', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAV', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OGG', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=883,
  serialized_end=930,
)
_sym_db.RegisterEnumDescriptor(_AUDIOEXT)

AudioExt = enum_type_wrapper.EnumTypeWrapper(_AUDIOEXT)
_AUDIOCODEC = _descriptor.EnumDescriptor(
  name='AudioCodec',
  full_name='ai.cogneed.cloud.speech.v1.AudioCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPUS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VORBIS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PCM', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=932,
  serialized_end=975,
)
_sym_db.RegisterEnumDescriptor(_AUDIOCODEC)

AudioCodec = enum_type_wrapper.EnumTypeWrapper(_AUDIOCODEC)
_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='ai.cogneed.cloud.speech.v1.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SESSION_DOES_NOT_EXISTS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=977,
  serialized_end=1044,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
WEBM = 0
MP3 = 1
WAV = 2
OGG = 3
OPUS = 0
VORBIS = 1
PCM = 2
OK = 0
SERVER_ERROR = 1
SESSION_DOES_NOT_EXISTS = 2



_AUDIOFORMAT = _descriptor.Descriptor(
  name='AudioFormat',
  full_name='ai.cogneed.cloud.speech.v1.AudioFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ext', full_name='ai.cogneed.cloud.speech.v1.AudioFormat.ext', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.cloud.speech.v1.AudioFormat.codec', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='ai.cogneed.cloud.speech.v1.AudioFormat.sample_rate', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='ai.cogneed.cloud.speech.v1.AudioFormat.channels', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_width', full_name='ai.cogneed.cloud.speech.v1.AudioFormat.sample_width', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=307,
)


_MODELCONFIG = _descriptor.Descriptor(
  name='ModelConfig',
  full_name='ai.cogneed.cloud.speech.v1.ModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.cloud.speech.v1.ModelConfig.use_case', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.cloud.speech.v1.ModelConfig.major', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=355,
)


_AUDIOINFO = _descriptor.Descriptor(
  name='AudioInfo',
  full_name='ai.cogneed.cloud.speech.v1.AudioInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='ai.cogneed.cloud.speech.v1.AudioInfo.format', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='g711_codec', full_name='ai.cogneed.cloud.speech.v1.AudioInfo.g711_codec', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='info', full_name='ai.cogneed.cloud.speech.v1.AudioInfo.info',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=358,
  serialized_end=499,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='ai.cogneed.cloud.speech.v1.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.cloud.speech.v1.UserInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.cloud.speech.v1.UserInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=541,
)


_PERSISTENCECONFIG = _descriptor.Descriptor(
  name='PersistenceConfig',
  full_name='ai.cogneed.cloud.speech.v1.PersistenceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='ai.cogneed.cloud.speech.v1.PersistenceConfig.record', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=578,
)


_INITSESSIONREQUEST = _descriptor.Descriptor(
  name='InitSessionRequest',
  full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_info', full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest.user_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio_info', full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest.audio_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.cloud.speech.v1.InitSessionRequest.persistence_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=792,
)


_DETECTIONRESPONSE = _descriptor.Descriptor(
  name='DetectionResponse',
  full_name='ai.cogneed.cloud.speech.v1.DetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='ai.cogneed.cloud.speech.v1.DetectionResponse.millisecond', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.cloud.speech.v1.DetectionResponse.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=851,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.cloud.speech.v1.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.AudioBlob.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=881,
)

_AUDIOFORMAT.fields_by_name['ext'].enum_type = _AUDIOEXT
_AUDIOFORMAT.fields_by_name['codec'].enum_type = _AUDIOCODEC
_AUDIOINFO.fields_by_name['format'].message_type = _AUDIOFORMAT
_AUDIOINFO.fields_by_name['g711_codec'].enum_type = cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2._G711CODEC
_AUDIOINFO.oneofs_by_name['info'].fields.append(
  _AUDIOINFO.fields_by_name['format'])
_AUDIOINFO.fields_by_name['format'].containing_oneof = _AUDIOINFO.oneofs_by_name['info']
_AUDIOINFO.oneofs_by_name['info'].fields.append(
  _AUDIOINFO.fields_by_name['g711_codec'])
_AUDIOINFO.fields_by_name['g711_codec'].containing_oneof = _AUDIOINFO.oneofs_by_name['info']
_INITSESSIONREQUEST.fields_by_name['user_info'].message_type = _USERINFO
_INITSESSIONREQUEST.fields_by_name['audio_info'].message_type = _AUDIOINFO
_INITSESSIONREQUEST.fields_by_name['persistence_config'].message_type = _PERSISTENCECONFIG
DESCRIPTOR.message_types_by_name['AudioFormat'] = _AUDIOFORMAT
DESCRIPTOR.message_types_by_name['ModelConfig'] = _MODELCONFIG
DESCRIPTOR.message_types_by_name['AudioInfo'] = _AUDIOINFO
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.message_types_by_name['PersistenceConfig'] = _PERSISTENCECONFIG
DESCRIPTOR.message_types_by_name['InitSessionRequest'] = _INITSESSIONREQUEST
DESCRIPTOR.message_types_by_name['DetectionResponse'] = _DETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.enum_types_by_name['AudioExt'] = _AUDIOEXT
DESCRIPTOR.enum_types_by_name['AudioCodec'] = _AUDIOCODEC
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioFormat = _reflection.GeneratedProtocolMessageType('AudioFormat', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOFORMAT,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioFormat)
  ))
_sym_db.RegisterMessage(AudioFormat)

ModelConfig = _reflection.GeneratedProtocolMessageType('ModelConfig', (_message.Message,), dict(
  DESCRIPTOR = _MODELCONFIG,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.ModelConfig)
  ))
_sym_db.RegisterMessage(ModelConfig)

AudioInfo = _reflection.GeneratedProtocolMessageType('AudioInfo', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOINFO,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioInfo)
  ))
_sym_db.RegisterMessage(AudioInfo)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINFO,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.UserInfo)
  ))
_sym_db.RegisterMessage(UserInfo)

PersistenceConfig = _reflection.GeneratedProtocolMessageType('PersistenceConfig', (_message.Message,), dict(
  DESCRIPTOR = _PERSISTENCECONFIG,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.PersistenceConfig)
  ))
_sym_db.RegisterMessage(PersistenceConfig)

InitSessionRequest = _reflection.GeneratedProtocolMessageType('InitSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONREQUEST,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.InitSessionRequest)
  ))
_sym_db.RegisterMessage(InitSessionRequest)

DetectionResponse = _reflection.GeneratedProtocolMessageType('DetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _DETECTIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.DetectionResponse)
  ))
_sym_db.RegisterMessage(DetectionResponse)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.audio_stream.common.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/predict-eval/predict-eval-api-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/predict-eval/predict-eval-api-service.proto',
  package='ai.cogneed.api.predict.predicteval',
  syntax='proto3',
  serialized_options=_b('\n\"ai.cogneed.api.predict.predictevalP\001'),
  serialized_pb=_b('\nBcogneed-protos/predict/predict-eval/predict-eval-api-service.proto\x12\"ai.cogneed.api.predict.predicteval\"_\n\x0eRequestFailure\x12\x0f\n\x07message\x18\x01 \x01(\t\x12<\n\x04\x63ode\x18\x02 \x01(\x0e\x32..ai.cogneed.api.predict.predicteval.StatusCode\"6\n\x11\x45valuationMetrics\x12\x11\n\tprecision\x18\x01 \x01(\x02\x12\x0e\n\x06recall\x18\x02 \x01(\x02\"w\n\nSetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\x12\x44\n\x05value\x18\x03 \x01(\x0b\x32\x35.ai.cogneed.api.predict.predicteval.EvaluationMetrics\"1\n\nGetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"u\n\x0bSetResponse\x12\x14\n\nnum_insert\x18\x01 \x01(\x05H\x00\x12\x45\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x32.ai.cogneed.api.predict.predicteval.RequestFailureH\x00\x42\t\n\x07\x63ontent\"\xa8\x01\n\x0bGetResponse\x12G\n\x06result\x18\x01 \x01(\x0b\x32\x35.ai.cogneed.api.predict.predicteval.EvaluationMetricsH\x00\x12\x45\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x32.ai.cogneed.api.predict.predicteval.RequestFailureH\x00\x42\t\n\x07\x63ontent*r\n\nStatusCode\x12\x18\n\x14MODEL_DOES_NOT_EXIST\x10\x00\x12 \n\x1cMODEL_KEYWORD_DOES_NOT_EXIST\x10\x01\x12\x16\n\x12\x42\x41\x44_INSERT_REQUEST\x10\x02\x12\x10\n\x0cSERVER_ERROR\x10\x03\x32\xe4\x01\n\x12PredictEvalService\x12\x66\n\x03get\x12..ai.cogneed.api.predict.predicteval.GetRequest\x1a/.ai.cogneed.api.predict.predicteval.GetResponse\x12\x66\n\x03set\x12..ai.cogneed.api.predict.predicteval.SetRequest\x1a/.ai.cogneed.api.predict.predicteval.SetResponseB&\n\"ai.cogneed.api.predict.predictevalP\x01\x62\x06proto3')
)

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='ai.cogneed.api.predict.predicteval.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODEL_DOES_NOT_EXIST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_KEYWORD_DOES_NOT_EXIST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_INSERT_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=721,
  serialized_end=835,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
MODEL_DOES_NOT_EXIST = 0
MODEL_KEYWORD_DOES_NOT_EXIST = 1
BAD_INSERT_REQUEST = 2
SERVER_ERROR = 3



_REQUESTFAILURE = _descriptor.Descriptor(
  name='RequestFailure',
  full_name='ai.cogneed.api.predict.predicteval.RequestFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ai.cogneed.api.predict.predicteval.RequestFailure.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='ai.cogneed.api.predict.predicteval.RequestFailure.code', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=201,
)


_EVALUATIONMETRICS = _descriptor.Descriptor(
  name='EvaluationMetrics',
  full_name='ai.cogneed.api.predict.predicteval.EvaluationMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='precision', full_name='ai.cogneed.api.predict.predicteval.EvaluationMetrics.precision', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recall', full_name='ai.cogneed.api.predict.predicteval.EvaluationMetrics.recall', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=257,
)


_SETREQUEST = _descriptor.Descriptor(
  name='SetRequest',
  full_name='ai.cogneed.api.predict.predicteval.SetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.predicteval.SetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.predicteval.SetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.cogneed.api.predict.predicteval.SetRequest.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=378,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='ai.cogneed.api.predict.predicteval.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.predicteval.GetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.predicteval.GetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=429,
)


_SETRESPONSE = _descriptor.Descriptor(
  name='SetResponse',
  full_name='ai.cogneed.api.predict.predicteval.SetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_insert', full_name='ai.cogneed.api.predict.predicteval.SetResponse.num_insert', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='ai.cogneed.api.predict.predicteval.SetResponse.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predicteval.SetResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=431,
  serialized_end=548,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='ai.cogneed.api.predict.predicteval.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai.cogneed.api.predict.predicteval.GetResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='ai.cogneed.api.predict.predicteval.GetResponse.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predicteval.GetResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=551,
  serialized_end=719,
)

_REQUESTFAILURE.fields_by_name['code'].enum_type = _STATUSCODE
_SETREQUEST.fields_by_name['value'].message_type = _EVALUATIONMETRICS
_SETRESPONSE.fields_by_name['failure'].message_type = _REQUESTFAILURE
_SETRESPONSE.oneofs_by_name['content'].fields.append(
  _SETRESPONSE.fields_by_name['num_insert'])
_SETRESPONSE.fields_by_name['num_insert'].containing_oneof = _SETRESPONSE.oneofs_by_name['content']
_SETRESPONSE.oneofs_by_name['content'].fields.append(
  _SETRESPONSE.fields_by_name['failure'])
_SETRESPONSE.fields_by_name['failure'].containing_oneof = _SETRESPONSE.oneofs_by_name['content']
_GETRESPONSE.fields_by_name['result'].message_type = _EVALUATIONMETRICS
_GETRESPONSE.fields_by_name['failure'].message_type = _REQUESTFAILURE
_GETRESPONSE.oneofs_by_name['content'].fields.append(
  _GETRESPONSE.fields_by_name['result'])
_GETRESPONSE.fields_by_name['result'].containing_oneof = _GETRESPONSE.oneofs_by_name['content']
_GETRESPONSE.oneofs_by_name['content'].fields.append(
  _GETRESPONSE.fields_by_name['failure'])
_GETRESPONSE.fields_by_name['failure'].containing_oneof = _GETRESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['RequestFailure'] = _REQUESTFAILURE
DESCRIPTOR.message_types_by_name['EvaluationMetrics'] = _EVALUATIONMETRICS
DESCRIPTOR.message_types_by_name['SetRequest'] = _SETREQUEST
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['SetResponse'] = _SETRESPONSE
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestFailure = _reflection.GeneratedProtocolMessageType('RequestFailure', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTFAILURE,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.RequestFailure)
  ))
_sym_db.RegisterMessage(RequestFailure)

EvaluationMetrics = _reflection.GeneratedProtocolMessageType('EvaluationMetrics', (_message.Message,), dict(
  DESCRIPTOR = _EVALUATIONMETRICS,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.EvaluationMetrics)
  ))
_sym_db.RegisterMessage(EvaluationMetrics)

SetRequest = _reflection.GeneratedProtocolMessageType('SetRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETREQUEST,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.SetRequest)
  ))
_sym_db.RegisterMessage(SetRequest)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

SetResponse = _reflection.GeneratedProtocolMessageType('SetResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.SetResponse)
  ))
_sym_db.RegisterMessage(SetResponse)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_eval.predict_eval_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predicteval.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)


DESCRIPTOR._options = None

_PREDICTEVALSERVICE = _descriptor.ServiceDescriptor(
  name='PredictEvalService',
  full_name='ai.cogneed.api.predict.predicteval.PredictEvalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=838,
  serialized_end=1066,
  methods=[
  _descriptor.MethodDescriptor(
    name='get',
    full_name='ai.cogneed.api.predict.predicteval.PredictEvalService.get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='set',
    full_name='ai.cogneed.api.predict.predicteval.PredictEvalService.set',
    index=1,
    containing_service=None,
    input_type=_SETREQUEST,
    output_type=_SETRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTEVALSERVICE)

DESCRIPTOR.services_by_name['PredictEvalService'] = _PREDICTEVALSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.trainui import record_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2


class RecordServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.create = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/create',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Create.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.read_audio = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/read_audio',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordAudio.FromString,
        )
    self.read = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/read',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Record.FromString,
        )
    self.list = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/list',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecords.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecordsResponse.FromString,
        )
    self.delete = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/delete',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.updateWindow = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/updateWindow',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.UpdateWindow.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.validate = channel.unary_unary(
        '/ai.cogneed.api.trainui.record.RecordService/validate',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class RecordServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def read_audio(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def read(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def list(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def updateWindow(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def validate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RecordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'create': grpc.unary_unary_rpc_method_handler(
          servicer.create,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Create.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'read_audio': grpc.unary_unary_rpc_method_handler(
          servicer.read_audio,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordAudio.SerializeToString,
      ),
      'read': grpc.unary_unary_rpc_method_handler(
          servicer.read,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.Record.SerializeToString,
      ),
      'list': grpc.unary_unary_rpc_method_handler(
          servicer.list,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecords.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.ListRecordsResponse.SerializeToString,
      ),
      'delete': grpc.unary_unary_rpc_method_handler(
          servicer.delete,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'updateWindow': grpc.unary_unary_rpc_method_handler(
          servicer.updateWindow,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.UpdateWindow.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'validate': grpc.unary_unary_rpc_method_handler(
          servicer.validate,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_record__pb2.RecordUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.trainui.record.RecordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.predict.mfcc_buffer import mfcc_buffer_service_pb2 as cogneed__protos_dot_predict_dot_mfcc__buffer_dot_mfcc__buffer__service__pb2


class MfccBufferServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.get_mfcc = channel.unary_unary(
        '/ai.cogneed.api.predict.mfccbuffer.MfccBufferService/get_mfcc',
        request_serializer=cogneed__protos_dot_predict_dot_mfcc__buffer_dot_mfcc__buffer__service__pb2.MfccBufferRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_predict_dot_mfcc__buffer_dot_mfcc__buffer__service__pb2.MfccBufferResponse.FromString,
        )


class MfccBufferServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def get_mfcc(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MfccBufferServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'get_mfcc': grpc.unary_unary_rpc_method_handler(
          servicer.get_mfcc,
          request_deserializer=cogneed__protos_dot_predict_dot_mfcc__buffer_dot_mfcc__buffer__service__pb2.MfccBufferRequest.FromString,
          response_serializer=cogneed__protos_dot_predict_dot_mfcc__buffer_dot_mfcc__buffer__service__pb2.MfccBufferResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.predict.mfccbuffer.MfccBufferService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/audio-stream-api/audio-stream-api-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.audio_stream.common import common_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/audio-stream-api/audio-stream-api-service.proto',
  package='ai.cogneed.api.audio.audiostream',
  syntax='proto3',
  serialized_options=_b('\n ai.cogneed.api.audio.audiostreamP\001'),
  serialized_pb=_b('\nKcogneed-protos/audio-stream/audio-stream-api/audio-stream-api-service.proto\x12 ai.cogneed.api.audio.audiostream\x1a/cogneed-protos/audio-stream/common/common.proto\"7\n\x13InitSessionResponse\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\t\",\n\tModelInfo\x12\r\n\x05major\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"\x9a\x02\n\tAudioBlob\x12\x39\n\naudio_info\x18\x01 \x01(\x0b\x32%.ai.cogneed.cloud.speech.v1.AudioInfo\x12I\n\x12persistence_config\x18\x02 \x01(\x0b\x32-.ai.cogneed.cloud.speech.v1.PersistenceConfig\x12?\n\nmodel_info\x18\x03 \x01(\x0b\x32+.ai.cogneed.api.audio.audiostream.ModelInfo\x12\x11\n\tcall_uuid\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x12\x12\n\nblob_index\x18\x06 \x01(\x03\x12\x0e\n\x06millis\x18\x07 \x01(\x03\"\x15\n\x13NoDetectionResponse\"\xa1\x01\n\x08Response\x12\x42\n\tdetection\x18\x01 \x01(\x0b\x32-.ai.cogneed.cloud.speech.v1.DetectionResponseH\x00\x12\x46\n\x05\x65mpty\x18\x02 \x01(\x0b\x32\x35.ai.cogneed.api.audio.audiostream.NoDetectionResponseH\x00\x42\t\n\x07\x63ontent\"&\n\x11\x45ndSessionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\"\x14\n\x12\x45ndSessionResponse2\xec\x02\n\x12StreamAudioService\x12u\n\x0cinit_session\x12..ai.cogneed.cloud.speech.v1.InitSessionRequest\x1a\x35.ai.cogneed.api.audio.audiostream.InitSessionResponse\x12\x65\n\nsend_audio\x12+.ai.cogneed.api.audio.audiostream.AudioBlob\x1a*.ai.cogneed.api.audio.audiostream.Response\x12x\n\x0b\x65nd_session\x12\x33.ai.cogneed.api.audio.audiostream.EndSessionRequest\x1a\x34.ai.cogneed.api.audio.audiostream.EndSessionResponseB$\n ai.cogneed.api.audio.audiostreamP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.DESCRIPTOR,])




_INITSESSIONRESPONSE = _descriptor.Descriptor(
  name='InitSessionResponse',
  full_name='ai.cogneed.api.audio.audiostream.InitSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.audiostream.InitSessionResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.audiostream.InitSessionResponse.major', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=217,
)


_MODELINFO = _descriptor.Descriptor(
  name='ModelInfo',
  full_name='ai.cogneed.api.audio.audiostream.ModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.audiostream.ModelInfo.major', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.audio.audiostream.ModelInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=263,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.api.audio.audiostream.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_info', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.audio_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.persistence_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_info', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.model_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.call_uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.blob_index', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millis', full_name='ai.cogneed.api.audio.audiostream.AudioBlob.millis', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=548,
)


_NODETECTIONRESPONSE = _descriptor.Descriptor(
  name='NoDetectionResponse',
  full_name='ai.cogneed.api.audio.audiostream.NoDetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=571,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='ai.cogneed.api.audio.audiostream.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection', full_name='ai.cogneed.api.audio.audiostream.Response.detection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty', full_name='ai.cogneed.api.audio.audiostream.Response.empty', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.audio.audiostream.Response.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=574,
  serialized_end=735,
)


_ENDSESSIONREQUEST = _descriptor.Descriptor(
  name='EndSessionRequest',
  full_name='ai.cogneed.api.audio.audiostream.EndSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.audiostream.EndSessionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=737,
  serialized_end=775,
)


_ENDSESSIONRESPONSE = _descriptor.Descriptor(
  name='EndSessionResponse',
  full_name='ai.cogneed.api.audio.audiostream.EndSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=797,
)

_AUDIOBLOB.fields_by_name['audio_info'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._AUDIOINFO
_AUDIOBLOB.fields_by_name['persistence_config'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._PERSISTENCECONFIG
_AUDIOBLOB.fields_by_name['model_info'].message_type = _MODELINFO
_RESPONSE.fields_by_name['detection'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._DETECTIONRESPONSE
_RESPONSE.fields_by_name['empty'].message_type = _NODETECTIONRESPONSE
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['detection'])
_RESPONSE.fields_by_name['detection'].containing_oneof = _RESPONSE.oneofs_by_name['content']
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['empty'])
_RESPONSE.fields_by_name['empty'].containing_oneof = _RESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['InitSessionResponse'] = _INITSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ModelInfo'] = _MODELINFO
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['NoDetectionResponse'] = _NODETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['EndSessionRequest'] = _ENDSESSIONREQUEST
DESCRIPTOR.message_types_by_name['EndSessionResponse'] = _ENDSESSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitSessionResponse = _reflection.GeneratedProtocolMessageType('InitSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.InitSessionResponse)
  ))
_sym_db.RegisterMessage(InitSessionResponse)

ModelInfo = _reflection.GeneratedProtocolMessageType('ModelInfo', (_message.Message,), dict(
  DESCRIPTOR = _MODELINFO,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.ModelInfo)
  ))
_sym_db.RegisterMessage(ModelInfo)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

NoDetectionResponse = _reflection.GeneratedProtocolMessageType('NoDetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _NODETECTIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.NoDetectionResponse)
  ))
_sym_db.RegisterMessage(NoDetectionResponse)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.Response)
  ))
_sym_db.RegisterMessage(Response)

EndSessionRequest = _reflection.GeneratedProtocolMessageType('EndSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.EndSessionRequest)
  ))
_sym_db.RegisterMessage(EndSessionRequest)

EndSessionResponse = _reflection.GeneratedProtocolMessageType('EndSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_api.audio_stream_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.audiostream.EndSessionResponse)
  ))
_sym_db.RegisterMessage(EndSessionResponse)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.api.audio.audiostream.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=800,
  serialized_end=1164,
  methods=[
  _descriptor.MethodDescriptor(
    name='init_session',
    full_name='ai.cogneed.api.audio.audiostream.StreamAudioService.init_session',
    index=0,
    containing_service=None,
    input_type=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._INITSESSIONREQUEST,
    output_type=_INITSESSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='send_audio',
    full_name='ai.cogneed.api.audio.audiostream.StreamAudioService.send_audio',
    index=1,
    containing_service=None,
    input_type=_AUDIOBLOB,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='end_session',
    full_name='ai.cogneed.api.audio.audiostream.StreamAudioService.end_session',
    index=2,
    containing_service=None,
    input_type=_ENDSESSIONREQUEST,
    output_type=_ENDSESSIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.public.audio import audio_api_pb2 as cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2


class StreamAudioServiceStub(object):
  """*
  Main service used in the real-time detection of keywords.
  The stream_audio method should be used to initialize the stream and then send audio data.
  The get_keyword_description method should be used the the detections to fetch the description to display.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.stream_audio = channel.stream_stream(
        '/ai.cogneed.audio.api.StreamAudioService/stream_audio',
        request_serializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.AudioDetectRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.DetectionResponse.FromString,
        )
    self.get_keyword_description = channel.unary_unary(
        '/ai.cogneed.audio.api.StreamAudioService/get_keyword_description',
        request_serializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.DescriptionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.DescriptionResponse.FromString,
        )


class StreamAudioServiceServicer(object):
  """*
  Main service used in the real-time detection of keywords.
  The stream_audio method should be used to initialize the stream and then send audio data.
  The get_keyword_description method should be used the the detections to fetch the description to display.
  """

  def stream_audio(self, request_iterator, context):
    """Method responsible for streaming the detections.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_keyword_description(self, request, context):
    """Method responsible for fetching the description to display given a keyword.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StreamAudioServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'stream_audio': grpc.stream_stream_rpc_method_handler(
          servicer.stream_audio,
          request_deserializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.AudioDetectRequest.FromString,
          response_serializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.DetectionResponse.SerializeToString,
      ),
      'get_keyword_description': grpc.unary_unary_rpc_method_handler(
          servicer.get_keyword_description,
          request_deserializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.DescriptionRequest.FromString,
          response_serializer=cogneed__protos_dot_public_dot_audio_dot_audio__api__pb2.DescriptionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.audio.api.StreamAudioService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
